// src/index.ts
import { generate, loadContext } from "@graphql-codegen/cli";
import { isMainThread, parentPort, Worker } from "worker_threads";
import { expose, wrap } from "comlink";
import nodeEndpoint from "comlink/dist/umd/node-adapter";

// src/config.ts
var tagStr2DtsConfig = {
  overwrite: true,
  schema: "schema.graphql",
  generates: {
    "./src/graphql.gql.ts": {
      plugins: ["typescript"]
    },
    "./": {
      documents: ["src/**/*.ts", "!src/**/*.gql.ts"],
      preset: "near-operation-file",
      presetConfig: {
        baseTypesPath: "./src/graphql.gql.ts",
        extension: ".gql.ts"
      },
      plugins: ["typescript-operations"]
    }
  }
};
var gql2TsConfig = {
  overwrite: true,
  schema: "schema.graphql",
  generates: {
    "./src/graphql.generated.ts": {
      plugins: ["typescript"]
    },
    "./": {
      documents: ["src/**/*.gql"],
      preset: "near-operation-file",
      presetConfig: {
        baseTypesPath: "./src/graphql.generated.ts",
        extension: ".generated.ts"
      },
      plugins: ["typescript-operations", "typed-document-node"]
    }
  }
};

// src/index.ts
import { pathExists } from "@liuli-util/fs-extra";
import * as path from "path";
async function codegenDts(watch, config) {
  try {
    if (await pathExists("codegen.yml")) {
      const codegenContext = await loadContext();
      codegenContext.updateConfig({
        watch
      });
      await generate(codegenContext);
    } else {
      await generate({
        ...config,
        cwd: path.resolve(),
        watch
      });
    }
  } catch (error) {
    console.log("Something went wrong.");
  }
}
if (!isMainThread) {
  expose(codegenDts, nodeEndpoint(parentPort));
}
function graphQLCodegen(config = tagStr2DtsConfig) {
  return {
    name: "rollup-plugin-graphql-codegen",
    async buildStart() {
      await codegenDts(false, config);
      if (this.meta.watchMode) {
        const worker = new Worker(__filename);
        const codegenWorker = wrap(nodeEndpoint(worker));
        codegenWorker(this.meta.watchMode, config);
      }
    }
  };
}
export {
  gql2TsConfig,
  graphQLCodegen,
  tagStr2DtsConfig
};
